@@ -476,6 +476,12 @@ void Theme::paint(cairo_t *c, const BackgroundImageConfig &cfg, int width,
         width = resizeWidth;
     }
 
+    const auto targetResizeWidth = width - marginLeft - marginRight;
+    const auto targetResizeHeight = height - marginTop - marginBottom;
+    const double scaleX = static_cast<double>(targetResizeWidth) / resizeWidth;
+    const double scaleY =
+        static_cast<double>(targetResizeHeight) / resizeHeight;
+
     cairo_save(c);
 
     /*
@@ -529,12 +535,10 @@ void Theme::paint(cairo_t *c, const BackgroundImageConfig &cfg, int width,
     }
 
     /* part 2 & 8 */
-    if (marginTop) {
+    if (marginTop && targetResizeWidth > 0) {
         cairo_save(c);
         cairo_translate(c, marginLeft, 0);
-        cairo_scale(
-            c, (double)(width - marginLeft - marginRight) / (double)resizeWidth,
-            1);
+        cairo_scale(c, scaleX, 1);
         cairo_set_source_surface(c, image, -marginLeft, 0);
         cairo_rectangle(c, 0, 0, resizeWidth, marginTop);
         cairo_clip(c);
@@ -542,12 +546,10 @@ void Theme::paint(cairo_t *c, const BackgroundImageConfig &cfg, int width,
         cairo_restore(c);
     }
 
-    if (marginBottom) {
+    if (marginBottom && targetResizeWidth > 0) {
         cairo_save(c);
         cairo_translate(c, marginLeft, height - marginBottom);
-        cairo_scale(
-            c, (double)(width - marginLeft - marginRight) / (double)resizeWidth,
-            1);
+        cairo_scale(c, scaleX, 1);
         cairo_set_source_surface(c, image, -marginLeft,
                                  -marginTop - resizeHeight);
         cairo_rectangle(c, 0, 0, resizeWidth, marginBottom);
@@ -557,12 +559,10 @@ void Theme::paint(cairo_t *c, const BackgroundImageConfig &cfg, int width,
     }
 
     /* part 4 & 6 */
-    if (marginLeft) {
+    if (marginLeft && targetResizeHeight > 0) {
         cairo_save(c);
         cairo_translate(c, 0, marginTop);
-        cairo_scale(c, 1,
-                    (double)(height - marginTop - marginBottom) /
-                        (double)resizeHeight);
+        cairo_scale(c, 1, scaleY);
         cairo_set_source_surface(c, image, 0, -marginTop);
         cairo_rectangle(c, 0, 0, marginLeft, resizeHeight);
         cairo_clip(c);
@@ -570,12 +570,10 @@ void Theme::paint(cairo_t *c, const BackgroundImageConfig &cfg, int width,
         cairo_restore(c);
     }
 
-    if (marginRight) {
+    if (marginRight && targetResizeHeight > 0) {
         cairo_save(c);
         cairo_translate(c, width - marginRight, marginTop);
-        cairo_scale(c, 1,
-                    (double)(height - marginTop - marginBottom) /
-                        (double)resizeHeight);
+        cairo_scale(c, 1, scaleY);
         cairo_set_source_surface(c, image, -marginLeft - resizeWidth,
                                  -marginTop);
         cairo_rectangle(c, 0, 0, marginRight, resizeHeight);
@@ -585,14 +583,7 @@ void Theme::paint(cairo_t *c, const BackgroundImageConfig &cfg, int width,
     }
 
     /* part 5 */
-    {
-        double scaleX = 1.0, scaleY = 1.0;
-        scaleX =
-            (double)(width - marginLeft - marginRight) / (double)resizeWidth;
-
-        scaleY =
-            (double)(height - marginTop - marginBottom) / (double)resizeHeight;
-
+    if (targetResizeHeight > 0 && targetResizeWidth > 0) {
         cairo_save(c);
         cairo_translate(c, marginLeft, marginTop);
         cairo_scale(c, scaleX, scaleY);
@@ -623,7 +614,6 @@ void Theme::paint(cairo_t *c, const BackgroundImageConfig &cfg, int width,
     clipRect.y = cfg.overlayClipMargin.marginTop;
     clipRect.width = clipWidth;
     clipRect.height = clipHeight;
-    ;
 
     int x = 0, y = 0;
     switch (cfg.gravity) {
